@@ -164,7 +164,9 @@ class BaseController(object):
 
     def finalize(self):
         #必要あれば子クラスでオーバーライド
-        pass        
+        try:
+            self.session.close()
+        except:pass
     
     def getCharSet(self):
         #必要あれば子クラスでオーバーライド
